package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$"`0`````````````"`!0````!`8`2$````#0``0.(```````T`"``
M"``H`!\`'@````8````T`8``-`&``#0```$````!``````0````$`````P``
M`30!@`$T`8`!-````!<````7````!`````$````!``````&````!@`````"8
MB```F(@````%``$```````$``/Z$`8'^A`&!_H0```*$```(``````8``0``
M`````@``_Q`!@?\0`8'_$````.````#@````!@````0````$```!3`&``4P!
M@`%,````+````"P````$````!&1TY5```)"T`8"0M`&`D+0```#T````]```
M``0````$9'3E4@``_H0!@?Z$`8'^A````7P```%\````!`````$O=7-R+VQI
M8F5X96,O;&0N96QF7W-O```````'````!`````%.971"4T0``#N:R@`````$
M````!`````-085@``````````$,```!A`````````!X```!9````!````!@`
M``!)````8````$P`````````2````!`````P````(P```%$`````````7P``
M`%8```!:````*P```"X``````````````"````!7````30````@```!<````
M0P```%L````Y````5````````````````````%T````&```````````````M
M````4P````````!2````%P```#L`````````6````!$````H````$@```$4`
M```R````-0`````````*````1``````````:`````````%4````T````````
M`%````!>````*0```$\````^````1P``````````````````````````````
M``````(```````````````<`````````!0````````````````````,`````
M```````````````````````````````.``````````D````,````&0``````
M```````````````````````````````````;`````````!,`````````````
M`!0`````````#0``````````````%@`````````=``````````L````!````
M``````\````Q```````````````O````(@`````````5````````````````
M`````````"$````Z````'``````````E````0@`````````?````0```````
M```]````.````"<````V````1@```$L```!!````+````#P````S````)@``
M``````!.````-P```````````````````"H```!*````)````#\`````````
M````````````````````````````````C@``````````$@````````P`````
M`````!(```````,U`8(&A``````0```;````%```````````$@```````SL!
M@!V0````$!(```H````<```````````2````````(@``````````$@``````
M`"D``````````!(````````O```````````2```````#3`&`)Y@````P$@``
M"@```#8``````````!(```````+_```````````2```````#9P&`-!0```&P
M$@``"@```'D``````````!(````````^`8!-```````2```````#<P&"`0@`
M````$```&0```$X``````````!(```````!=```````````2````````8P``
M````````$@```````&H``````````!(```````!T```````````2````````
M?@&`49``````$@``"P```(0``````````!(```````"-```````````2````
M```"8@``````````$@```````),``````````!(```````":```````````2
M```````#)```````````$@```````*@!@@$8`````1$``!L```*A````````
M```B````````M0``````````$@```````WH!@"!8````.!(```H```.'`8`@
MD````#`2```*```#DP&`*2````B,$@``"@```L(``````````!(```````##
M```````````6````````U@``````````$@```````Q$``````````!(`````
M``#A```````````2````````Z@&"`1`````$$0``&@```/(``````````!(`
M``````+U```````````2````````_@``````````$@```````04`````````
M`!(```````.@`8!$I````<@2```*```!&`&"`1P````@$0``&P```2H`````
M`````!(```````$Z```````````2```````!2```````````$@```````4T!
M@?Z8````$Q$``!(```%<```````````2```````#JP&"`00````$$0``&0``
M`6L``````````!(```````%W```````````2```````!C```````````$@``
M`````9<!@$[0`````!(```````,V`8(&A``````0```;```"D@``````````
M$@```````:H``````````!(```````/F`8`2$````!P2```*```!N```````
M````$@```````<```````````!(```````',```````````2```````#M0&`
M(,````8H$@``"@```=(``````````!(```````'=```````````2```````#
MP@&`1FP```%P$@``"@```>X``````````!(```````/,`8(!"``````0```:
M```#V`&`'5@````X$@``"@```^`!@$G(```"C!(```H```'U```````````2
M```````">@``````````(@```````^4!@!(0````'!(```H```/M`8`=H```
M`K@2```*```#^@&`)\@```%8$@``"@``!`P!@";H````L!(```H```'\`8!/
M@``````2```````"6P``````````$@```````@T``````````!(```````(6
M```````````2```````"'```````````$@```````N@``````````!(`````
M``(A```````````2```````"VP&"`0@````$$0``&@```BD``````````!(`
M``````,&```````````2```````",```````````$@``````!!H!@$0T````
M<!(```H```(W`8(!0````0@1```;```"T`&"`0`````$$0``&0``!!T!@!'L
M`````!(```D```0C`8`QK````F@2```*```!$0``````````$@```````CP`
M`````````!(```````,8```````````2`````&QI8G!E<FPN<V\`<F5A;&QO
M8P!M96UM;W9E`')M9&ER`'-T<G-T<@!C;&]S90!S=')C:'(`<W1R;F-M<`!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?
M;'-T870U,`!P97)L7V9R964`7V9I;FD`7U]S=&%T-3``7V5X:70`;65M8W!Y
M`'!E<FQ?9&5S=')U8W0`4$Q?9&]?=6YD=6UP`%!E<FQ?<W9?<V5T<'8`4$Q?
M8W5R<F5N=%]C;VYT97AT`'!E<FQ?86QL;V,`8VQO<V5D:7(`96YV:7)O;@!?
M7V]P96YD:7(S,`!M96US970`4&5R;%]S869E<WES;6%L;&]C`%]?<W1A8VM?
M8VAK7V=U87)D`%!E<FQ?9W9?9F5T8VAP=@!?7W-P<FEN=&9?8VAK`')E860`
M4$Q?;65M;W)Y7W=R87``4&5R;%]S>7-?:6YI=#,`4&5R;%]G971?<W8`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]N97=84P!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S>7-?=&5R;0!?7V5R<FYO`%!E<FQ?;6=?<V5T`&UK9&ER`'!E
M<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A8V-E<W,`9V5T<&ED`%!E<FQ?
M871F;W)K7VQO8VL`<&5R;%]R=6X`;'-E96L`;W!E;@!S<')I;G1F`&=E='5I
M9`!S=')L96X`7U]S1@!S=')C;7``;&EB;2YS;RXP`&QI8F-R>7!T+G-O+C$`
M<W1R9'5P`&9P<FEN=&8`;&EB<'1H<F5A9"YS;RXQ`%]?9&5R96=I<W1E<E]F
M<F%M95]I;F9O`'!T:')E861?871F;W)K`%]?<F5G:7-T97)?9G)A;65?:6YF
M;P!L:6)C+G-O+C$R`%]?<W1R;F-P>5]C:&L`7U]P<F]G;F%M90!?7W!S7W-T
M<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!A=&5X:70`7VQI8F-?:6YI
M=`!S=')T;VL`7U]R96%D9&ER,S``7U]S=&%C:U]C:&M?9F%I;`!?7V5N9`!P
M87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%]E9&%T80!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R
M7VUK=&UP9&ER`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!S
M:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!M86EN`%]?<W1A<G0`<&%R
M7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<VAA
M7VEN:70`6%-?26YT97)N86QS7U!!4E]"3T]4`"]U<W(O<&MG+VQI8B]P97)L
M-2\U+C,X+C`O<&]W97)P8RUN971B<V0M=&AR96%D+6UU;'1I+T-/4D4Z+W5S
M<B]P:V<O;&EB``````&!_O@``!X!``````&!_PP``$D!``````&!__```"1)
M``````&!_I@``#(3``````&"`1@``!T3``````&"`1P``"X3``````&"`4``
M`%H3``````&"``````$5``````&"``0```(5``````&"``@```05``````&"
M``P```85``````&"`!````<5``````&"`!0```@5``````&"`!@```D5````
M``&"`!P```L5``````&"`"````P5``````&"`"0```X5``````&"`"@```\5
M``````&"`"P``!$5``````&"`#```!(5``````&"`#0``!,5``````&"`#@`
M`!05``````&"`#P``!45``````&"`$```!<5``````&"`$0``!@5``````&"
M`$@``!D5``````&"`$P``!H5``````&"`%```!L5``````&"`%0``!P5````
M``&"`%@``!X5``````&"`%P``!\5``````&"`&```",5``````&"`&0``"45
M``````&"`&@``"85``````&"`&P``"<5``````&"`'```"D5``````&"`'0`
M`"H5``````&"`'@``"L5``````&"`'P``"P5``````&"`(```"\5``````&"
M`(0``#`5``````&"`(@``#$5``````&"`(P``#,5``````&"`)```#45````
M``&"`)0``#85``````&"`)@``#<5``````&"`)P``#@5``````&"`*```#H5
M``````&"`*0``#L5``````&"`*@``#T5``````&"`*P``#X5``````&"`+``
M`#\5``````&"`+0``$$5``````&"`+@``$(5``````&"`+P``$05``````&"
M`,```$@5``````&"`,0``$D5``````&"`,@``$X5``````&"`,P``$\5````
M``&"`-```%`5``````&"`-0``%$5``````&"`-@``%(5``````&"`-P``%,5
M``````&"`.```%05``````&"`.0``%85``````&"`.@``%<5``````&"`.P`
M`%@5``````&"`/```%X5``````&"`/0``%\5``````&"`/@``&`5`````'P(
M`J:0`0`$E"'_\$@`-N4X(0`0@`$`!'P(`Z9.@``@`````$*?``5]:`*F/:L`
M`CFM;NQ\XSMX?01#>$@``4V4(?_@?`@"ID*?``63P0`8?\@"IC_>``*3@0`0
M.]YL>)`!`"2!7H``@YZ`!'P*X$!`@`!T.YS__Y/A`!Q_BN!0DZ$`%%><\+X[
MJO_\._P``7/I``%!@@`<@2H``'U=4WA]*0.F3H`$(7^?XWE!@@`P@3T`!#N=
M``0[____.[T`"'TI`Z9.@`0A@3P`!'TI`Z9.@`0A-____T""_]B#H0`4@^$`
M'(`!`"2#@0`0@\$`&'P(`Z8X(0`@3H``()0A_^!\"`*F0I\`!9/!`!A_R`*F
M/]X``I.!`!`[WFN\D^$`'(.>@`R#_H`(D`$`)'P?X$!`@``XDZ$`%(D_``<L
M"0#X0((`1($_``@[_P`,@[__]'TI`Z9.@`0A?!_@0)!]``!!@/_8@Z$`%(`!
M`"2#@0`0@\$`&'P(`Z:#X0`<."$`($Z``"!(`#FQE"'_X'P(`J9"GP`%DV$`
M#'R;(WF3P0`8?\@"IC_>``*0`0`DDT$`"#O>:S"3@0`0DZ$`%)/A`!Q!@@&0
M@3L``(#^@!2!20``@UZ`&"P*``"!&P`(DV<``)$:``!!@@%<@1Z`')%(``"!
M*0``B4D``"P*``!!@@`@*`H`+SDI``%`@O_LD2@``(E)```L"@``0(+_Z"P#
M``!!@@`(2``XT4@`.^V!/H`D+`D``$&"`4"!7H`H@YZ`+'P*X$!`@`!D.YS_
M_SNJ__Q_BN!05YSPOCO\``%SZ0`!08(`'($J``!]75-X?2D#IDZ`!"%_G^-Y
M08(`,($]``0[G0`$.____SN]``A]*0.F3H`$(8$\``1]*0.F3H`$(3?___]`
M@O_8@'Z`,$@`.$F!7H`T@YZ`.'P*X$!`@`!D.YS__SNJ__Q_BN!05YSPOCO\
M``%SZ0`!08(`'($J``!]75-X?2D#IDZ`!"%_G^-Y08(`,($]``0[G0`$.___
M_SN]``A]*0.F3H`$(8$\``1]*0.F3H`$(3?___]`@O_8@'Z`/$@`-]%+__S9
M@+H``(";``"`>P`$2``TI4@`-SF!/H`<@5Z`()%)``!+__[0@-Z`$#C@`!,X
MH``".&```#B```1,QC&"2``XW3A@``%(`#@52__]B4O__L"4(?_0DX$`('Q\
M&WF3X0`L08(`W#T@`8*380`<@VD!$"P;``!!@@#0DT$`&'R:(WB3H0`D?YWC
M>(D\```L"0``08(`P"@)`#U!@@`0C3T``2P)``!`@O_P?[SH4(/[```L'P``
M08(`I'P(`J:3P0`HD`$`-']^VWA_I>MX?X3C>'_C^WA(`#;E+`,``$""`!!]
M/^BN+`D`/4&"`#R'_@`$+!\``$""_]2``0`T@T$`&(-A`!Q\"`.F@Z$`)(/!
M`"A_X_MX@X$`((/A`"PX(0`P3H``('_;\%`[O0`!?]X6<'__ZA23V@``2___
MP#O@``!+___0@V$`'#O@``!+___$.Z```$O__UB#00`8@V$`'(.A`"1+__^L
ME"'_,).A`,1\?1MYD^$`S#_@`8([_P$<@3\``)$A`*PY(```08(`$(D]```L
M"0``0((`*($A`*R!7P``?2E2>3E```!`@@%4@Z$`Q(/A`,PX(0#03H``('P(
M`J:3P0#(D`$`U$@`-SU\?AMY08(!%)-!`+@_0`&`DX$`P#M:4?Q_P_-X2``Y
M/2P#``!!@@"PB2,`#3N#``TU*?_20((`$(D\``$L"0``08+_V(DC``TU*?_2
M08(`L'^CZWB380"\2``XT7Q[&WA_@^-X2``XQ7Q[&A0X8P`"2``XR7^&XWA_
MI>MX?'P;>']$TWA,QC&"2``X<3B!`!!_@^-X2``UY2P#__]_@^-X08(`%($A
M`!A5*00F+`E``$&"`'A(`#65?X/C>$@`-4U_P_-X@V$`O$@`.)$L`P``0(+_
M6'_#\WA(`#91?Z/K>$@`-,F``0#4@T$`N(.!`,!\"`.F@\$`R$O__M2)/``!
M-2G_TD"B_TR)/``"+`D``$&"_PA+__\\@`$`U(/!`,A\"`.F2__^J$O__G%+
M__^,?`@"II-!`+B0`0#4DV$`O).!`,"3P0#(2``U@90A_T!\"`*FD^$`O#_@
M`8([_P$<.($`$)/!`+B!/P``D2$`K#D@``"0`0#$?'X;>$@`--TL`P``0((`
M.($A`!A5*00F*`E``$&"`!!M*O__+`J@`$""`"!_P_-X.(```D@`-KU\8P`T
M5&/9?D@```@X8```@2$`K(%?``!]*5)Y.4```$""`!R``0#$@\$`N(/A`+Q\
M"`.F."$`P$Z``"!(`#3=E"'_X'P(`J:3X0`<?'\;>)`!`"1(`#<E.*/__WR_
M*A1\'RA`0:``%$@``2@XI?__?!\H0$&"`2"))0``+XD`+T&>_^Q`@`$,?^GX
M^'TE2A1Q*@`!08(`$(U%__\L"@`O08(`-%4I^'XY*0`!?2D#ID@``!"-)?__
M+`D`+T&"`!@XI?__0D``T(DE```L"0`O0(+_Y'_I^/A])4H4<2H``4&"`!PX
MI?__?!\H0$"``%B)10``+`H`+T""`$PY1?__52GX?GP?4$`Y*0`!08$`?"P?
M__]`H@`@2```<(E%```L"@`O0((`((U%__\L"@`O0((`%"P)``$XI?__.2G_
M_T""_]Q\ORA0.&```#DE``(H"00`08$`(#T@`8(XI0`!.2D"='_D^WA](TMX
M.,`$`$@`,]F``0`D@^$`'#@A`"!\"`.F3H``(#D@``%+__^H0(+_1(D_```\
M8`&`.&-1S"P)`"]!@@`,/&`!@#AC4<B``0`D@^$`'#@A`"!\"`.F2``U.)0A
M_[!\"`*FD`$`5)-A`#R3@0!`DZ$`1#^@`8*3P0!(.[T!')/A`$Q\?QMXDR$`
M-(%=``"100`<.4```)-!`#B))```:2D`/2$I``!_Q`&4?\/S>$@`-6$X@0`8
M?'L;>'_C^WA,QC&"2__ZI7Q\&WE!@@$H2``U07P;&$!`@0#X@R$`&#]``8)7
M.1`ZB3\``'_J^W@L"0``0*(`%$@``;R-*@`!+`D``$&"``PH"0`]0(+_\'U?
M4%`X>P`"@YH!$'QC4A1(`#4!+`,``'Q\R2Y!@@!DB5\``($A`!B!&@$0+`H`
M`%4I$#I]"$@NF4@``$"B`!A(``"<C5\``2P*``"920`!08(`C"@*`#U]"4-X
M.0@``4""_^0Y0``].][__YE)``"-7@`!+`H``)U)``%`@O_T@2$`'(%=``!]
M*5)Y.4```$""`2B``0!4@R$`-(-!`#A\"`.F@V$`/(.!`$"#H0!$@\$`2(/A
M`$PX(0!03H``(#O>__\[G/__C5X``2P*``"=7``!0(+_]$O__ZA]"4-X2___
MA#]``8*2X0`LDP$`,(+Z`1"!-P``+`D``$&"`+!^Z;MX.X```(5)``1_B.-X
M.YP``2P*``!`@O_P.0@``U4$$#H](`&".2D"=(%)!``L"@``0((`4#E```%\
M@R-XD4D$`$@`,\U\>!MY08(`>%>9$#I^Y+MX?R7+>$@`,!63&@$0.3P``3E`
M``!5*1`Z?5A)+I.!`!B"X0`L@P$`,$O__EA^X[MX2``OV2P#``"0>@$0?'@;
M>$&"`"Q7F1`Z2___Q#E```!+__Y<.(``"#N```!+__]PDN$`+),!`#!(`##A
M@N$`+(,!`#!+__ZTE"'_X'P(`J8\P`&!/*`!@)/A`!P_X`&".___])`!`"2#
M___\/(`!@'__$A0XQI!4@'\``#BE30`XA%($2``QI8`!`"0\X`&`@'\``#CG
M5,B#X0`</*`!@#R``8!\YCMX.*4QK#B$4B`Y````?`@#IC@A`"!(`#'L/2`!
M@I0A__`Y*?_T/,`!@8$I__P\H`&`?2D2%#R``8"`:0``.,:05#BE30`XA%($
M."$`$$@`,324(?_P.&```#@A`!!.@``@E"'[$'V``"8]0`&`?`@"II+A!,P^
MX`&"DZ$$Y#KW`1R3X03L?'T;>'R?(W@X:E(X.($`')`!!/23@03@@3<``)$A
M!+PY(```D8$$P$S&,8)+__=Y?'P;>#B``"]_H^MX2``NP2P#``!!@@!8/&`!
M@'^DZW@X8U)$3,8Q@DO__$%_H^MX@2$$O(%7``!]*5)Y.4```$""`@2``03T
M@8$$P(+A!,Q\"`.F@X$$X'V`@2"#H03D@^$$[#@A!/!.@``@DV$$W'^CZW@_
M8`&`DT$$V#M[4E1(`#&=?'H;>']DVWA_X_MX2``O?7Q_&WE!@@&@DJ$$Q"X<
M``"2P03(/J`!@),!!-`ZP```DR$$U#\``8`_(`&`D\$$Z#M:``$ZM5',.QA1
MR#LY4EABUH``.\```(D_```L"0``08(`V$&2`!A_Y/MX?X/C>$@`,4DL`P``
M08(`B'_C^WA(`#$9?5\:%(DJ__\L"0`O0((`''_I^/A\:5(4G\K__XD*__\L
M"``O08+_\'QZ&A0L`P/_08$`9'_G^WA_J>MX?PC#>'\FRW@XH`0`.(```#AA
M`+Q,QC&"2``O(3B!`"`X80"\2``N!2P#``!`@@`4@2$`*%4I!"9\";``08(`
M:']DVW@X8```2``N@2P#``!\?QMX0(+_1(*A!,2"P03(@P$$T(,A!-2#0038
M@V$$W(/!!.A+__Y@09(`$(D\```U*?_208(`$'Z_JW@X8``!2___7(D\``$L
M"0``08+_I$O__^@X@``!.&$`O$@`+VTL`P``0(+_C#Q@`8`X@0"\.&-21$S&
M,8)+__I=.&$`O$@`+XF"H03$@L$$R(,!!-"#(034@T$$V(-A!-R#P03H2__]
M_(-!!-B#803<2__]V)*A!,22P03(DP$$T),A!-230038DV$$W)/!!.A(`"U=
ME"'_\'QI&WB)0P``+`H``$&"`"`H"@`O.2D``4"B``A](TMXB4D``"P*``!`
M@O_H."$`$$Z``"!\:1MYE"'_\$&"`!B)*0``+`D``$&"``PX(0`02__X+#Q@
M`8`X(0`0.&-1S$@`+M24(?^@/(`!@3B$D%1\"`*FD^$`7#_@`8*3P0!8._\!
M'#B$``PXH``B.&$`&#_``8"3H0!4@3\``)$A`#PY(```D`$`9#O>4F"3(0!$
M/Z`!@I-!`$B380!,DX$`4$@`+'4X@0`4?\/S>$S&,8)+__0]+`,``$&"`$R!
M00`4@1T!$%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``E4D`!$""
M__0X@0`4?\/S>$S&,8)+__/U+`,``$""_[P_P`&`/Z`!@CO>4FPX@0`4?\/S
M>$S&,8)+__/1+`,``$&"`$R!00`4@1T!$%5*$#I]*%(4@.D`!"P'``!\Z%$N
M0:+_S(%)``@L"@``E4D`!$""__0X@0`4?\/S>$S&,8)+__.)+`,``$""_[P_
MP`&`/Z`!@CO>4G0X@0`4?\/S>$S&,8)+__-E+`,``$&"`$R!00`4@1T!$%5*
M$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``E4D`!$""__0X@0`4?\/S
M>$S&,8)+__,=+`,``$""_[P_P`&`/Z`!@CO>4H`X@0`4?\/S>$S&,8)+__+Y
M+`,``$&"`$R!00`4@1T!$%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L
M"@``E4D`!$""__0X@0`4?\/S>$S&,8)+__*Q+`,``$""_[P_P`&`/Z`!@CO>
M4H@X@0`4?\/S>$S&,8)+__*-+`,``$&"`$R!00`4@1T!$%5*$#I]*%(4@.D`
M!"P'``!\Z%$N0:+_S(%)``@L"@``E4D`!$""__0X@0`4?\/S>$S&,8)+__)%
M+`,``$""_[P_H`&`/X`!@CN]4I@X@0`4?Z/K>$S&,8)+__(A+`,``$&"`$R!
M00`4@1P!$%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``E4D`!$""
M__0X@0`4?Z/K>$S&,8)+__'9+`,``$""_[P_H`&`/X`!@CN]4C@X@0`4?Z/K
M>$S&,8)+__&U+`,``$&"`$R!00`4@1P!$%5*$#I]*%(4@.D`!"P'``!\Z%$N
M0:+_S(%)``@L"@``E4D`!$""__0X@0`4?Z/K>$S&,8)+__%M+`,``$""_[P_
M@`&`/V`!@CN<4J0X@0`4?X/C>$S&,8)+__%)+`,``$&"`$R!00`4@1L!$%5*
M$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``E4D`!$""__0X@0`4?X/C
M>$S&,8)+__$!+`,``$""_[P_8`&`/T`!@CM[4K`X@0`4?V/;>$S&,8)+__#=
M+`,``$&"`$R!00`4@1H!$%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L
M"@``E4D`!$""__0X@0`4?V/;>$S&,8)+__"5+`,``$""_[P_0`&`/R`!@CM:
M4KPX@0`4?T/3>$S&,8)+__!Q+`,``$&"`$R!00`4@1D!$%5*$#I]*%(4@.D`
M!"P'``!\Z%$N0:+_S(%)``@L"@``E4D`!$""__0X@0`4?T/3>$S&,8)+__`I
M+`,``$""_[P_0`&`/R`!@CM:4D0X@0`4?T/3>$S&,8)+__`%+`,``$&"`$R!
M00`4@1D!$%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``E4D`!$""
M__0X@0`4?T/3>$S&,8)+_^^]+`,``$""_[P\8`&`.($`%#AC4LA,QC&"2__O
MH7QD&WE!@@`0?V/;>$S&,8)+__2!/&`!@#B!`!0X8U+<3,8Q@DO_[WE\9!MY
M08(`%#Q@`8`X8U'03,8Q@DO_]%4\8`&`.($`%#AC4O!,QC&"2__O37QD&WE!
M@@!D?Z/K>$S&,8)+__0M/(`!@'_#\W@XA%,@3,8Q@DO_]!F!(0`\@5\``'TI
M4GDY0```0((`C(`!`&2#(0!$@T$`2'P(`Z:#80!,@X$`4(.A`%2#P0!8@^$`
M7#@A`&!.@``@/&`!@#B!`!0X8U,`3,8Q@DO_[M%\9!MY08(`%'^#XWA,QC&"
M2__SL4O__X0\@`&`.*``"CB$4Q0X80`I2``F#2P#``!`@O]H?X/C>#B!`#-,
MQC&"2__S@4O__U1(`";-E"'_T)/!`"@_P`&"@'X`_)/A`"P_X`&"+`/__SO_
M`1R!/P``D2$`'#D@``!!@@`H@2$`'(%?``!]*5)Y.4```$""`&2#P0`H@^$`
M+#@A`#!.@``@/&`!@'P(`J8X@0`8.&-2I)`!`#1,QC&"2__N%7QI&WDX8```
M08(`'(DI```L"0``08(`$&DI`#`P:?__?&-)$(`!`#20?@#\?`@#IDO__Y!\
M"`*FD`$`-$@`)AV4(?_P?`@"II`!`!1(`"A-2``H*2P#``!!@@`(@&,``(`!
M`!0X(0`0?`@#IDZ``""4(?_`?`@"II.A`#0_H`&`D^$`/#N]4R0_X`&"DX$`
M,#O_`1Q\?!MX.($`&'^CZWB3P0`X@3\``)$A`!PY(```D`$`1$S&,8)+_^U9
M?'X;>4&"`!")/@``+`D``$""`$2!(0`<@5\``'TI4GDY0```0((`X'^$XWA_
MH^MX@`$`1(.!`#"#H0`T?`@#IH/!`#B#X0`\."$`0$S&,8)+__'X?X3C>$@`
M)#4L`P``08(`.($A`!R!7P``?2E2>3E```!`@@"0@`$`1(.!`#"#H0`T?`@#
MIH/!`#B#X0`\."$`0$Z``"!_@^-XDV$`+$@`)UU\>QMX?\/S>$@`)U%\>QH4
M.&,``D@`)U4\P`&`/(`!@'_'\WA_A>-X.,925#B$4EA\?AMX3,8Q@D@`)O&!
M(0`<@5\``'TI4GDY0```0((`&(-A`"Q_Q/-X?Z/K>$O__S"380`L2``DE3P`
M__\](`&!.2F05&``?J!\+`MX@0D`,'PA`6Y\"`*F@4D`.#B```"`J0`TDTS_
MZ&"$@2R3;/_L/V`!@).,__`_@`&"D^S__#N<`1R0#``$.WM2.)+L_]Q\>AMX
MDPS_X']CVWB3+/_DDZS_])/,__B`R0`\@.D`0(%\``!]9`DN.6```)$!`"`X
M@0`<@0D`1)%!`"B!20!(D*$`))#!`#B0X0`\@,D`3(#I`%"1`0!`D4$`1($)
M`%2!20!8@2D`7)#!`$B0X0!,D0$`+)%!`#"1(0`T3,8Q@DO_ZW%\?QMY08(`
M$(D_```L"0``0(($I$@`)>%(`"6]+`,``$&"!`R#PP``+!X``$&"!`!_P_-X
M2``EX51C"#PX8P`!2``EY8B^``!\>1MX+`4``$&"`#`_H`&`?S_+>#N]4SQ_
MX_MX?Z3K>$S&,8)(`"5YC+X``3O_``(L!0``0(+_Y#Q@`8`[P0`X.&-1T$@`
M`!"$?@`$+`,``$&"`$`X@0`<3,8Q@DO_ZLE\?QMY0:+_Y(D_```L"0``08+_
MV$O_[7TL`P``08+_S'_C^WA(`"3)?'\;>4"B`&@[P```.P$`(#E```!7R1`Z
M84J!,'U*2A1]*@H4/2G__X/I?O`L'P``08(`.%?=$#I_N.H4B3\``"P)``!!
M@@`D?^/[>#O>``%+_^T9+`,``$""`0R'_0`$+!\``$""_]@[X```?^/[>#\`
M`8!(`"31.QA1R'Q^&WA_(\MX2``DP7_>&A0[W@0$?\/S>$@`),$\X`&`/(`!
M@'\HRWA_Y?MX?P;#>'Q]&W@XYU-$.(133$S&,8)(`"19?Z/K>#B``<!(`".-
M+`/__T&"`D@X@0!0?Z/K>$@`(9E\?QMY08(`E("Z```\@`&`/&`!@G^FZW@X
MA%.4.&,!\$S&,8)(`"&Q.\```#D@``!A*8$L?4D(+H$\``!]2DIY.2```$""
M!;B!80``?\/S>(`+``2"Z__<@PO_X'P(`Z:#*__D@TO_Z(-K_^R#B__P@ZO_
M](/+__B#Z__\?6%;>$Z``"!_X_MX2``C77Q_&WE!@OZ@2__^^($A`%A5*00F
M+`E``$""_V2#(0!L2``CF7P9&`!`@O]4@2$`6%4I!?XL"0'`0(+_1'_#\WA(
M`".I.($`''Q^&W@\8`&`.&-3Z$S&,8)+_^C9+`,``$&"`I"#.@``2``B\7QD
M&WA_(\MX2__P]7QW&WE!@@)T?N.[>$@`(U4H`P`#?'D;>$"!`#@\@`&`.&/_
M_#B$4_!\=QH42``C52P#``!`@@`<*!D`!$&"`^A_-\H4B3G_^RP)`"]!@@/8
M/R`!@H$Y`/PL"?__08(#B"P)```_0`&`.UI2I$&"`A@\@`&`?T/3>#B$4R`_
M0`&`3,8Q@DO_[2D[6E3(2``B)3R``8!\9QMX?TC3>#B$5!!_!L-X?Z7K>'_#
M\W@_(`&`3,8Q@D@`(GT[.50@2```0$@`(9&!(P``+`D`$4""`$1(`"'A._\`
M`7QG&WA_Z/MX?TG3>'\&PWA_I>MX?R3+>'_#\WA,QC&"2``B.3B``<!_P_-X
M2``A;2P#__]!@O^T?Z/K>$@`'RU_8]MX?\3S>$S&,8)+_^R)?\/S>$O_^>U+
M__WX2``A'8$C```L"0`108+]L(/Z``!(`"$)@.,``#R``8`\8`&"?^7[>'^F
MZW@XA%-8.&,!\#O```!,QC&"2``?84O__;0Y(8$P.Z```#L!`"P[*7[L.4``
M`%>I$#IA2H$P?4I*%'TJ"A0]*?__@&E^_"P#``!!@@"T5[X0.CO]``%_V/(4
M2```%(1^``0L`P``08(`F#O_``%_),MX?_W[>$S&,8)+_^;A?&D;>4&B_]R)
M*0``+`D``$&"_]!(`"#Q?'X;>4""^X1+__^,2__Y&3D@``!A*8$L?4D(+H$\
M``!]2DIY.2```$""`MR!80``?^/[>(`+``2"Z__<@PO_X'P(`Z:#*__D@TO_
MZ(-K_^R#B__P@ZO_](/+__B#Z__\?6%;>$@`((@X8``-/\`!@$@`(0T[WE,T
M?'D;>#B@`%-+__LL@OH``$O__8R1.0#\?N.[>#B```!,QC&"2``@@3]``8!\
M>1MY.UI2I$&"_=`XX``".*#__SC`_^Y(`"!1.($!+#B@``9_(\MX2``?$8DA
M`2PL"0``0((`$(DA`2TL"0!#08(!E#C@```XH```.,```'\CRWA(`"`5.^``
M`$@`%)%C_X``?'H;>$@``!`X@0$L?T/3>$@`%.E_Y?MX.($!+'\CRWA(`!ZU
M?&4;>4&!_^!_(\MX/R`!@$@`'-%_1--X.2&!,#AA`.P[27_0.^$`ZT@`%G4[
M.5,\.N$`_XB_``%_),MX?T/3>#M:``),QC&"2``?R8B_``)_0]-X._\``G\D
MRW@[6@`"3,8Q@D@`'ZU\'[A`0(+_R#T``8`\@`&`.2```'\&PW@Y"%3(..$!
M`'^EZW@XA%0`?\/S>)DA`2A,QC&"2``?=7^CZWA(`!Q]?V/;>'_$\WA,QC&"
M2__IV7_#\WA+__<]2__[2#]``8`X@0`<.UI2I']#TWA,QC&"2__DP2P#``!!
M@@!DB2,``"P)``!!HOYT*`D`,$&"`-@Y(``!D3D`_$O__%"#6@`$+!H``$&B
M_"1_0]-X2``?+2@#``-`H?P4.&/__#R``8!\>AH4.(13^$@`'S$L`P``0*+[
M^']7TWA+__OPD'D`_$O__AR)(0$N+`D`04""_FB)(0$O+`D`0T""_ER)(0$P
M+`D`2$""_E")(0$Q+`D`14""_D0XX``".,#_QCB@__]_(\MX2``>53B!`2Q_
M(\MX.*``*4@`'14]``&`/(`!@#CA`2Q_!L-X.0A4R#B$5`!_I>MX?\/S>$S&
M,8)(`!Y-2__\*#D@``"1.0#\2__]D$@`'`F4(?_`?`@"ICQ@`8"3X0`\/^`!
M@CO___23@0`PD`$`1($___R380`L?2D2%).A`#0_@`&"D\$`.#N<`1R!7```
MD4$`'#E````X@0`8@2D``#AC4HB)20!DF4D`94S&,8)+_^-=+`,``$&"`!")
M(P``+`D`,4&"`6Q+_^Z=@]___#R``8!_WA(4.(14-(!^```XP``#.*```4@`
M'!U\?1MY08(`,($]``P\H`&`@'X``#BE5#B`B0``2``;;8$]``R`B0``@20`
M"'4I`$!`@@%L@]___#R``8!_WA(4.(140(!^```XP``#.*```4@`&\E\>QMY
M08(`,#Q@`8`X@0`8.&-21$S&,8)+_^*U?&4;>4&"`02!.P`,@'X``(")``!(
M`!L%/Z`!@CN]`G2#___\/(`!@'__$A0XA%1$@]\``#B@``%_P_-X2``;K3R@
M`8!\9!MX.*547'_#\WA(`!K)@3\``#E````\8`&`F4D`93B!`!@X8U(X3,8Q
M@DO_XD$L`P``D'T$"$&"`&@X@`'`2``;Y2P#`!%!@@`0.2,``2@)``%!@0"@
M@2$`'(%<``!]*5)Y.4```$""`*R``0!$@V$`+(.!`#!\"`.F@Z$`-(/!`#B#
MX0`\."$`0$Z``"")(P`!+`D``$&B_I1+__Z,@'T$!$O_]8$L`P``D'T$"$""
M_XP\8`&`.&-49$S&,8)(`!KU/Z`!@H%;``P[O0)T@'X``($]!`2`B@``@*D`
M`$@`&?5+__[X@'X``$@`&RE+__Z0@5T$!#T@`8"`O00(?&8;>("*```X:52(
M3,8Q@D@`&J5(`!FAE"'_P'V``"9\"`*FD8$`+"X#``"3X0`\/^`!@CO_`1R3
MH0`TD`$`1'Q]&WB3@0`P@3\``)$A`!PY(```D\$`.$&2`*2)(P``+`D``$&"
M`)A+_^1UB2,``'Q^&W@L"0``08(`("@)`"\X8P`!0*(`"'Q^&WB)(P``+`D`
M`$""_^@_@`&"@3P`_"P)__]!@@!H+`D``$&"`!1!D@`0B3T``"P)``!`@@"0
M@2$`'(%?``!]*5)Y.4```$""`/2``0!$@8$`+(.!`#!\"`.F@Z$`-'V`@2"#
MP0`X@^$`/#@A`$!.@``@/&`!@#AC4<Q(`!J12___9#Q@`8`X@0`8.&-2I$S&
M,8)+_^!1+`,``$&"`(2)(P``+`D``$&"`(`H"0`P08(`@#D@``&1/`#\0)+_
M<$O__W@\@`&`?\/S>#B$4T0XH``$2``7>2P#``!`@O]<@2$`'(%?``!]*5)Y
M.4```$""`$R!@0`L?Z/K>(`!`$2#@0`P?8"!((.A`#1\"`.F@\$`.(/A`#PX
M(0!`2__@X)!\`/Q+__\4D3P`_$O__PPY(```D3P`_$O__P!(`!?QE"'^@'P(
M`J8X@P`<.*``0)/!`7@_P`&"D^$!?#O>`1Q\?QMX.&$`'($^``"1(0%<.2``
M`)`!`82300%HDV$!;).!`7"3H0%T2``7A3D@`$`Y00`8?2D#IGU(4WB$Z@`$
M@2@`.(#(`"2!"``,?2DR>'TI0GA]*3IX52D(/I$J`$!"`/_8@)\`!($A`!R`
M?P`(5)OP/H#?``P]*5J"@4$`('QHVGB!?P``?'TR>("_`!`\ZEJ".2EYF8%!
M`"158"@^?[T@.'T(6#A]*2H4..=YF7^],GA\YS(4?2D"%'T(&GA58/`^?2GJ
M%'T(.A0_JEJ"@.$`*']J`GA5/"@^?4I(.#N]>9E5*?`^?0CB%'U*VGA_O1H4
M/X=:@GP'2GA]2NH4?.=`.(.A`"P[G'F951HH/G^<VA15"/`^?.<">'U*TA1]
M+$)X?.?B%#^]6H*#@0`P.[UYF7V,4#A56R@^?!T"%%5*\#Y]C$IX/YQ:@GSG
MVA1]'5)X?8P"%#@<>9F#@0`T5/LH/G^].#A4Y_`^?8S:%'T@2A1_O4)X?4`Z
M>#^<6H)_O4H4.YQYF56)*#Y\`&`X?[U*%'T<0A2!(0`X?`!2>%6,\#Y\`$(4
M5Z@H/GP`0A0_B5J"@0$`/'SI8GA]*>@X.YQYF5>]\#Y_G%(4/0A:@GTJ.GA]
MB>IX5!LH/GU*XA0Y"'F9@X$`0'TI`#A]2MH45`#P/GSH.A1]*6)X?Z@">#]\
M6H)]*3H455PH/GTIXA0[>WF9@X$`1'T(4#A51_`^?9MB%'T(ZGA\"CIX/WQ:
M@GT(8A15/"@^?4I(.'T(XA0[>WF9@X$`2%4I\#Y_>^H4?4H">'S]2G@_7%J"
M?4K:%%4<*#Y]2N(4?[U`.(.!`$P[6GF950CP/G]:`A1_O3IX?2!">#]\6H)_
MO=(455PH/GP`4#A_O>(4.WMYF8.!`%!52O`^?WLZ%'P`2GA]!U)X/UQ:@GP`
MVA17O"@^?`#B%'SGZ#B#@0!4.UIYF7]:2A1\Z4)X5[WP/C]\6H)]*=(45!PH
M/GTIXA1]1^IX@X$`6'SG`#@[>WF95`#P/G][0A1\YU)X?Z@">#]<6H)]"$@X
M53PH/GSGVA0[6GF9?.?B%']:4A2#@0!<?0KJ>%4I\#Y]2M(45.@H/GP,2GA]
M"D(4/WQ:@H%!`&!]C#@X.WMYF53G\#Y_>^H4/XI:@GV=`GB!00!D?2PZ>'^]
MVA1]C$`X51LH/CN<>9E5"/`^?[W:%'^<`A0]2EJ"?8!*>'SL0GA7NR@^?`#B
M%#E*>9F#@0!H?8SH.'P`VA17O?`^?2I*%'V,.GA]"NIX?8Q*%#^<6H)4"2@^
M?8Q*%'U*`#B!(0!L.YQYF7^<.A1]1T)X5`#P/CU);MI\Y^(459PH/GSGXA2!
M(0!P?[P">#E*ZZ%_G&)X?4I"%%6,\#X]"6[:?4KB%%3\*#Y]2N(4@2$`='P<
M8G@Y".NA?YPZ>'T(ZA1]".(45/WP/E5<*#X\Z6[:?0CB%($A`'A]G.IX..?K
MH7^<4GA\YP(4?.?B%%5`\#Y5'"@^/4ENVGSGXA2!(0!\?[P">#E*ZZ%_G$)X
M?4IB%'U*XA15#/`^5/PH/CT);MI]2N(4@2$`@'P<8G@Y".NA?YPZ>'T(ZA1]
M".(45/WP/E5<*#X\Z6[:?0CB%($A`(1]G.IX..?KH7^<4GA\YP(4?.?B%%5`
M\#Y5'"@^/4ENVGSGXA2!(0"(?[P">#E*ZZ%_G$)X?4IB%'U*XA15#/`^5/PH
M/CT);MI]2N(4@2$`C'P<8G@Y".NA?YPZ>'T(ZA1]".(45/WP/E5<*#X\Z6[:
M?0CB%($A`)!]G.IX..?KH7^<4GA\YP(4?.?B%%5`\#Y5'"@^/4ENVGSGXA2!
M(0"4?[P">#E*ZZ%_G$)X?4IB%'U*XA15#/`^5/PH/CT);MI]2N(4@2$`F'P<
M8G@Y".NA?YPZ>'T(ZA1]".(45/WP/E5<*#X\Z6[:?0CB%($A`)Q]G.IX..?K
MH7^<4GA\YP(4?.?B%%5`\#Y5'"@^/4ENVGSGXA2!(0"@?[P">#E*ZZ%_G$)X
M?4IB%'U*XA15#/`^5/PH/CT);MI]2N(4@2$`I'P<8G@Y".NA?YPZ>'T(ZA1]
M".(45/WP/E5<*#X\Z6[:?0CB%($A`*A]G.IX..?KH7^<4GA\YP(4?.?B%%5`
M\#Y5'"@^/4ENVGSGXA2!(0"L?[P">#E*ZZ%_G$)X?4IB%'U*XA15#/`^5/PH
M/CT);MI]2N(4@2$`L'P<8G@Y".NA?YPZ>'T(ZA1]".(45/WP/E5<*#X\Z6[:
M?0CB%($A`+1]G.IX..?KH7^<4GA\YP(4?.?B%%5`\#Y5'"@^/4ENVGSGXA2!
M(0"X?[P">#E*ZZ%_G$)X@V$`O'U*8A15"/`^?4KB%#TI;MI4_"@^?!I">'U*
MXA0Y*>NA5/SP/C][CQQ_1SIX?2GJ%#M[O-Q]'>-X?WL"%'TI.A1]`.`X54<H
M/G^]4#A]*3H4?[T#>(#A`,!52O`^53HH/G^]VA1_@%-X?[W2%#SGCQR#00#$
M?YM0.#CGO-Q\`$@X?0="%%4I\#Y\`-MX/WJ/''U'2WA\`$(4.WN\W%>H*#Y\
M`$(4?YOB%($!`,A]6T@X?.?H.%>]\#Y\Y]MX?2SK>%0;*#Y\Y^(4/0B/''SG
MVA1]/.@X@V$`S#D(O-Q]C``X?4A2%'V,XWA4`/`^/YN/''V,4A14ZB@^?8Q2
M%'^H`WB!00#0.YR\W'T\2A1]"#@X?[P`.%3G\#Y]".-X/VJ/'%6<*#Y\"CMX
M?0A*%#M[O-Q]".(4?WOJ%(.!`-1\'3@X?4I@.%6)\#Y]2NMX/9R/''U*VA15
M'"@^?4KB%'S]2WB#@0#8.8R\W'^]0#A]C`(4?.!(.%4(\#Y_H`-X/WR/''T]
M0WA57"@^?`!B%#M[O-Q\`.(4?[U0.(.!`-Q_>SH4?2=`.%5*\#Y_ISMX/9R/
M''SGVA14'"@^?.?B%'T=4WB#@0#@.8R\W'^]`#A]C$H4?0E0.%0`\#Y_J4MX
M/WR/''U=`WA4_"@^?2EB%#M[O-Q]*>(4?[TX.(.!`.1_>T(4?4@`.%3G\#Y_
MJ$-X/9R/''T(VA15/"@^?0CB%'P=.WB#@0#H.8R\W'^]2#A]C%(4?`HX.%4I
M\#Y_JE-X/WR/''S]2WA5'"@^?4IB%#M[O-Q]2N(4?WL"%(.!`.Q\X$@X?[U`
M.%4(\#Y_O0-X/9R/''^]VA157"@^?[WB%'T@0WB#@0#P.8R\W'V,.A1\`%`X
M?2=`.%5*\#Y\`#MX/WR/''T'4WA7O"@^?`!B%#M[O-Q\`.(4?.?H.(.!`/1_
M>TH4?0E0.%>]\#Y\Z4MX/9R/''TIVA14'"@^?2GB%'U'ZWB#@0#X.8R\W'V,
M0A1\YP`X?4CH.%0`\#Y\YT-X/WR/''^H`WA5/"@^?.=B%#M[O-Q\Y^(4?WM2
M%(.!`/Q_J@`X?0A(.%4I\#Y]"%-X/9R/''T(VA14_"@^?0CB%'P*2WB#@0$`
M.8R\W'V,ZA1]2C@X?!U(.%3G\#Y]2NMX/YR/''T].WA5&R@^?4IB%#F<O-R#
M@0$$?4K:%'^]0#A].S@X50CP/GP,`A1_O=MX?.Q#>#^<CQQ56R@^?[T"%#N<
MO-Q50/`^?8Q0.(%!`0A]/$H4?/Q`.'^]VA1]C.-X/XJ/''V,2A1]"@-X5ZDH
M/CN<O-Q]C$H4?4KH.'^<.A2!(0$,?0<`.%>]\#Y]1SMX/4G*8WSGXA15G"@^
M?.?B%($A`1!\'.IX.4K!UG^<8GA]2D(458SP/CT)RF-]2N(45/PH/GU*XA2!
M(0$4?[QB>#D(P=9_G#IX?0@"%'T(XA14X/`^55PH/CSIRF-]".(4@2$!&'V<
M`G@XY\'6?YQ2>'SGZA1\Y^(455WP/E4<*#X]2<IC?.?B%($A`1Q\'.IX.4K!
MUG^<0GA]2F(4?4KB%%4,\#Y4_"@^/0G*8WU*XA2!(0$@?[QB>#D(P=9_G#IX
M?0@"%'T(XA14X/`^55PH/CSIRF-]".(4@2$!)'V<`G@XY\'6?YQ2>'SGZA1\
MY^(455WP/E4<*#X]2<IC?.?B%($A`2A\'.IX.4K!UG^<0GA]2F(4?4KB%%4,
M\#Y4_"@^/0G*8WU*XA2!(0$L?[QB>#D(P=9_G#IX?0@"%'T(XA14X/`^55PH
M/CSIRF-]".(4@2$!,'V<`G@XY\'6?YQ2>'SGZA1\Y^(455WP/E4<*#X]2<IC
M?.?B%($A`31\'.IX.4K!UG^<0GA]2F(4?4KB%%4,\#Y4_"@^/0G*8WU*XA2!
M(0$X?[QB>#D(P=9_G#IX?0@"%'T(XA14X/`^55PH/CSIRF-]".(4@2$!/'V<
M`G@XY\'6?YQ2>'SGZA1\Y^(455WP/E4<*#X]2<IC?.?B%($A`4!\'.IX.4K!
MUG^<0GA]2F(4?4KB%%4,\#Y4_"@^/0G*8WU*XA2!(0%$?[QB>#D(P=9_G#IX
M?0@"%'T(XA14X/`^55PH/CSIRF-]".(4@2$!2'V<`G@XY\'6?YQ2>'SGZA1\
MY^(455WP/E4<*#X]2<IC@2$!3'SGXA0Y2L'6?!SJ>'^<0GA]2F(450SP/CT)
MRF.!(0%0?4KB%%3\*#XY",'6?4KB%#TIRF-_O&)X?0@"%'^<.G@Y*<'65.#P
M/GT(XA151R@^?2GJ%(.A`51]"#H4?9P">(#A`5A_G%)X/[W*8U5*\#Y]*>(4
M51LH/GP<4G@[O<'6/.?*8WTIVA1_G$)X?[UB%%4(\#XXY\'6?[WB%'SG6A1]
M7$)X52LH/G^<2GA\YP(4?7U:%'SGXA158"@^?.<"%%4I\#Z0_P``?09"%'U%
M4A1\A%H4?2D:%(#A`5R`W@``?.<R>3C```"17P`0D1\`#)"?``21/P`(0((`
M+(`!`82#00%H@V$!;'P(`Z:#@0%P@Z$!=(/!`7B#X0%\."$!@$Z``"!(``F!
ME"'_\'P(`J8X8`!@D`$`%$@`"]T\P._-/."8NCT`$#(]0,/2/(!G16#%JXE@
MA",!8.;<_F$'5'9A2.'P.4```)"#``"0HP`$D,,`")#C``R1`P`0D4,`%)%#
M`!B10P!<@`$`%#@A`!!\"`.F3H``()0A_]!\"`*F5*D8.%2H'WZ300`8?)HC
M>)-A`!R3@0`@?+PK>)/A`"Q\?QMXD`$`-#M_`!R3H0`D@4,`%(!C`%Q]*5(4
M@/\`&'U*2!`L`P``?4I1$)$_`!1]2CA0?0A2%)$?`!A!@@!((2,`0'R]*WA\
M!4@`08$!*'Q[&A1_I>MX?T33>$@`"&F!/P!<?3U*%"P)`$"1/P!<0*(`X'_C
M^WA_G>!0?UKJ%$O_\'DL'``_0($`M#N<_\"3(0`45YG1OI,!`!`[&0`!D\$`
M*',)``%_7=-X?Q[#>$&"`"PXH`!`?T33>']CVW@[N@!`2``(`7_C^WA+__`M
M+!D``'\^RWA!@@!(?Z3K>#B@`$!_8]MX.[T`0$@`!]E_X_MX2__P!7^DZW@X
MH`!`?V/;>$@`!\$[WO__?^/[>#N]`$!+_^_E-][__T""_\`?.?_`5Q@P,G]:
MPA2#P0`H?YGB%(,!`!"#(0`4?T33>']CVWA_A>-X2``'?9.?`%R``0`T@T$`
M&(-A`!Q\"`.F@X$`((.A`"2#X0`L."$`,$Z``"!]/4MX?'L:%'^EZWA_1--X
M2``'08$_`%Q]/4H4+`D`0)$_`%Q`@O^X2__^V)0A_]!\"`*F.4#_@).A`"0[
MI``<D\$`*'Q^&WB3X0`L?)\C>)`!`#2380`<DX$`((.$`!2#9``85XGNOCBI
M``%]74FN+`4`.'Q]*A1`@0$4(*4`0#B```!(``=]?^/[>$O_[OE_H^MX.*``
M.#B```!(``=EDW\`5'_C^WB3GP!82__NV8D_``!_X_MXF3X``*$_``"9/@`!
M@3\``%4IPCZ9/@`"@3\``)D^``.)/P`$F3X`!*$_``29/@`%@3\`!%4IPCZ9
M/@`&@3\`!)D^``>)/P`(F3X`"*$_``B9/@`)@3\`"%4IPCZ9/@`*@3\`")D^
M``N)/P`,F3X`#*$_``R9/@`-@3\`#%4IPCZ9/@`.@3\`#)D^``^)/P`0F3X`
M$*$_`!"9/@`1@3\`$%4IPCZ9/@`2@3\`$)D^`!.``0`T@V$`'(.!`"!\"`.F
M@Z$`)(/!`"B#X0`L."$`,$@`!2@@I0`X.(```$@`!FU+__\(E"'_X'P(`J9"
MGP`%D\$`&'_(`J8_W@`"D`$`)#O>-PB!'H`$B2@`)"P)``!`@@"HDX$`$#C@
M``&!7H`4@YZ`&)CH`"1\"N!`0(``=#N<__^3X0`<?XK@4).A`!17G/"^.ZK_
M_#O\``%SZ0`!08(`'($J``!]75-X?2D#IDZ`!"%_G^-Y08(`,($]``0[G0`$
M.____SN]``A]*0.F3H`$(8$\``1]*0.F3H`$(3?___]`@O_8@Z$`%(/A`!R!
M/H`<+`D``$&"`"2`?H`,2``&R8.!`!"``0`D@\$`&#@A`"!\"`.F3H``((`!
M`"2#@0`0@\$`&'P(`Z8X(0`@3H``()0A_^!\"`*F0I\`!9/!`!A_R`*F/]X`
M`I`!`"0[WC8(@)Z`!(DD```L"0``0((`I($^@`@Y0``!DZ$`%"P)``"91```
M08(`$(!^@`PXA``$2``$E8.^@`"!/H`0?!U(0$"!`(23@0`0.YW__W^)X%"3
MX0`<5YSPOCO\``%SZ0`!08(`&(4]__Q]*0.F3H`$(7^?XWE!@@`P@3W__#N=
M__P[____.[W_^'TI`Z9.@`0A@3S__'TI`Z9.@`0A-____T""_]B#@0`0@Z$`
M%(/A`!R``0`D@\$`&#@A`"!\"`.F3H``((.A`!1+___HE"'_P'P(`J:3P0`X
M/\`!@I!A`!P[W@$<D($`&#AA`!R0H0`4.($`&#BA`!2!/@``D2$`+#D@``"0
M`0!$DZ$`-)/A`#Q(``2%/*`!@#Q@`8`XI4[0.&-/@'RD*W@_X`&"2``$N3T@
M`8*+J0$8.___]"P=``!!@@%T@Z$`'(/___Q__Q(4/2!``(%?```X?0`$?`-(
M0#N]``.)*@/682D``YDJ`]9`@`&\5&,0.C_@`8)(``/9@($`'(%!`!@](`&"
M+`0``8#I`02`J@``/0`!@#T@`8`Y"%3,.2E4T#O_`G20HP``?&8;>)$#``20
MXP`(D2,`#)!_!`1`@0&`.23__SCD__YQ*``!.0,`#$""`,15*?A^?2D#IH!J
M``0XZ@`$.2@`!#E*``B0:``$.0@`"(#G``20Z0`$0@#_X#DD``-5*1`Z.4``
M`(!_!`P\@`&`?49)+G^EZW@XA!S@..```$@`!`E\?1MY08(`K(!_!`Q(``)I
M/&`!@#B!`"@X8U*83,8Q@DO_RATL`P``08(`F(!_!`Q(``'U2``#D8$A`"R!
M7@``?2E2>3E```!`@@#<@`$`1'^CZWB#P0`X@Z$`-'P(`Z:#X0`\."$`0$Z`
M`"`L!P``A.H`!'QH&WB4Z``00(+_,$O__UA(``)!/4`!@BP#``"0:@:`08(`
MB$@``4V!/__\?2D2%($I``";J09V2__^:(!_!`Q(``/!?'T;>$O__TR`?P0(
M+`,``$&"``Q+_^@=2___7#Q@`8`X@0`H.&-2.$S&,8)+_\E9+`,``)!_!`A!
M@O\\2__G]4O__S0\@`&"/&`!@#B$_I@X8U0,3,8Q@D@``G4Y(``$2__^Q#A@
M``%(```52``!86````!@````8````#U@`8*!:P``?6D#IDZ`!"`]8`&"@6L`
M!'UI`Z9.@`0@/6`!@H%K``A]:0.F3H`$(#U@`8*!:P`,?6D#IDZ`!"`]8`&"
M@6L`$'UI`Z9.@`0@/6`!@H%K`!1]:0.F3H`$(#U@`8*!:P`8?6D#IDZ`!"`]
M8`&"@6L`''UI`Z9.@`0@/6`!@H%K`"!]:0.F3H`$(#U@`8*!:P`D?6D#IDZ`
M!"`]8`&"@6L`*'UI`Z9.@`0@/6`!@H%K`"Q]:0.F3H`$(#U@`8*!:P`P?6D#
MIDZ`!"`]8`&"@6L`-'UI`Z9.@`0@/6`!@H%K`#A]:0.F3H`$(#U@`8*!:P`\
M?6D#IDZ`!"`]8`&"@6L`0'UI`Z9.@`0@/6`!@H%K`$1]:0.F3H`$(#U@`8*!
M:P!(?6D#IDZ`!"`]8`&"@6L`3'UI`Z9.@`0@/6`!@H%K`%!]:0.F3H`$(#U@
M`8*!:P!4?6D#IDZ`!"`]8`&"@6L`6'UI`Z9.@`0@/6`!@H%K`%Q]:0.F3H`$
M(#U@`8*!:P!@?6D#IDZ`!"`]8`&"@6L`9'UI`Z9.@`0@/6`!@H%K`&A]:0.F
M3H`$(#U@`8*!:P!L?6D#IDZ`!"`]8`&"@6L`<'UI`Z9.@`0@/6`!@H%K`'1]
M:0.F3H`$(#U@`8*!:P!X?6D#IDZ`!"`]8`&"@6L`?'UI`Z9.@`0@/6`!@H%K
M`(!]:0.F3H`$(#U@`8*!:P"$?6D#IDZ`!"`]8`&"@6L`B'UI`Z9.@`0@/6`!
M@H%K`(Q]:0.F3H`$(#U@`8*!:P"0?6D#IDZ`!"`]8`&"@6L`E'UI`Z9.@`0@
M/6`!@H%K`)A]:0.F3H`$(#U@`8*!:P"<?6D#IDZ`!"`]8`&"@6L`H'UI`Z9.
M@`0@/6`!@H%K`*1]:0.F3H`$(#U@`8*!:P"H?6D#IDZ`!"`]8`&"@6L`K'UI
M`Z9.@`0@/6`!@H%K`+!]:0.F3H`$(#U@`8*!:P"T?6D#IDZ`!"`]8`&"@6L`
MN'UI`Z9.@`0@/6`!@H%K`+Q]:0.F3H`$(#U@`8*!:P#`?6D#IDZ`!"`]8`&"
M@6L`Q'UI`Z9.@`0@/6`!@H%K`,A]:0.F3H`$(#U@`8*!:P#,?6D#IDZ`!"`]
M8`&"@6L`T'UI`Z9.@`0@/6`!@H%K`-1]:0.F3H`$(#U@`8*!:P#8?6D#IDZ`
M!"`]8`&"@6L`W'UI`Z9.@`0@/6`!@H%K`.!]:0.F3H`$(#U@`8*!:P#D?6D#
MIDZ`!"`]8`&"@6L`Z'UI`Z9.@`0@/6`!@H%K`.Q]:0.F3H`$(#U@`8*!:P#P
M?6D#IDZ`!"`]8`&"@6L`]'UI`Z9.@`0@/6`!@H%K`/A]:0.F3H`$($@``0!(
M``#\2```^$@``/1(``#P2```[$@``.A(``#D2```X$@``-Q(``#82```U$@`
M`-!(``#,2```R$@``,1(``#`2```O$@``+A(``"T2```L$@``*Q(``"H2```
MI$@``*!(``"<2```F$@``)1(``"02```C$@``(A(``"$2```@$@``'Q(``!X
M2```=$@``'!(``!L2```:$@``&1(``!@2```7$@``%A(``!42```4$@``$Q(
M``!(2```1$@``$!(```\2```.$@``#1(```P2```+$@``"A(```D8````&``
M``!@````8````&````!@````8````&`````]@`&"/6O^@(`,__@Y:Z^P?`D#
MIGP+6A2!C/_\?6!:%$Z`!"!@````8````&````!@````8````&````!@````
M?`@"II`!``24(?_P2__V03@A`!"``0`$?`@#IDZ``"!P<U]S=')I;F=S(&UI
M<W-I;F<*`"]T;7`O````+@```%!!4E]435!$25(``%1%35!$25(`5$U0`%53
M15(`````55-%4DY!344`````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````4$%27U1%35``````
M4$%27U!23T=.04U%`````#H````E<R5S)7,``%!%4DPU3$E"`````%!%4DQ,
M24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%2
M7T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT``#$```!,
M1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````'!A<BT`````)7,E<R5S
M)7,`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@``4$%42`````!P87)L`````"YP87(`````)7,E<V-A
M8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S````
M`!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U
M,@```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`````+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#
M86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I
M;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R
M7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E
M;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A8
M6"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M
M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@
M=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII
M9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@
M,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L
M;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D
M9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U
M=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N
M9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3
M,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G
M;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T
M85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N
M(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY("1B=68["FUY
M("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@
M,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE
M*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E
M("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T[
M"GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]
M"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P
M;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D
M4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!
M1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I
M8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@
M,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@
M)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L
M:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*
M96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D
M("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M(#T*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC
M<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O
M<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D
M=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I
M;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R
M(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO
M9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@
M,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D
M<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=
M('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG
M="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P
M;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME
M>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B
M72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?
M(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO
M861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X
M("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I
M;G0H)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@
M9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@
M(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M
M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*
M96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M
M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N
M*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I
M9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;
M4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC
M;&]S92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT
M96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E
M;B!A<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE
M+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D
M9F@I.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T
M.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE
M7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C
M86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F
M:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P
M96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP
M(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.
M5GM005)?5$5-4'TB72D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES
M1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N
M86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T
M7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI
M('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A
M;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T
M<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(ETI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]
M?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI
M;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D
M8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU
M."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E
M('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM
M>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\
M.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N
M86UE(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C
M='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L
M<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@
M)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B
M.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U
M;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O
M<B!D:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@
M)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@``<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("```````8!1Q`&`4<P``````8!1T`&`4=0!@%'<`8!2/`&`4>0``````8!1
MZ`&`4?```````1L#.P```/`````=__^!>````0C__X(T```!//__@L````%\
M__^$M````DS__X7,```"N/__AX````,L__^()````UC__XFH```#B/__C"P`
M``/D__^,I```!`S__XS<```$)/__C.P```0\__^/I```!,S__X_<```$Y/__
MD`P```4$__^6-```!43__Y;D```%?/__EQ0```6<__^8;```!>3__Z#X```&
M//__HV````9T__^E$```!O3__[.````',/__L_````=0__^UN```!YC__[<H
M```"!/__N"@```'`__^Y%```!L3__[NL```!K````!```````7I2``1\00$;
M#`$`````,````!C__X!H````O`!!#B!!"4$`0IX"1IP$$4%_19\!0IT#5]U!
MWT0&04'>W`X``````#P```!,__^`\````(P`00X@00E!`$*>`D6<!)\!1!%!
M?T*=`TS=1`9!0M_>W`X`00X@G`2=`YX"GP$107\````L````C/__@3P```'T
M`$$.($$)00!"FP5"G@)$F@8107]"G`1!G0-!GP$````````0````O/__N?@`
M``4P`````````$````#0__^V8````.P`00X@00E!`$*>`D<107]$G0-+G`1#
MGP%5W$'=0=]#W@X`009!00X@G0.>`A%!?T'=````````1````13__[4<```!
M``!!#B!!"4$`0IX"1Q%!?T*<!$B?`4*=`U?=0=]&W$/>#@!!!D%!#B"<!)X"
M$4%_0MQ"!D%!W@X`````:````5S__X)@```!&`!!#C!!G`1"GP%#FP5$F@9"
MG0-."4$`09X"01%!?T_:0=M!!D%!W4'>1-_<#@!!#C":!IL%G`2=`YX"GP$1
M07]&VMO=W@9!0IL%0=M"F@:;!9T#0]I!VT'=````````<````<C__X,,```!
MM`!!#M`!09T#0I\!40K?W0X`00M!"4$`09X"01%!?T2:!D*<!%&;!5S;20K:
M0=Q!!D%!WD$+1]K<0MY!!D%!F@:;!9P$G@(107]"VMO<W@9!00E!`$&:!D$1
M07]!FP5!G`1!G@(````H```"//__A$P```"D`$$.P`%""4$`GP%(G@(107];
M"@9!0=_>#@!!"P```"P```)H__^$Q````80`00X@0@E!`)\!0A%!?P)+"M\.
M`$$&04$+3=\.`$$&00```%@```*8__^&&````H0`00Y011%!?YL%G`2=`T2>
M`I\!2YD'F@8"00H&04;?WMW<V]K9#@!!"TN7"4&8"&,*UT'800M(U]A"EPF8
M"$/7V$&7"4&8"$+70=@`````)````O3__XA`````>`!!#B!$"4$`GP%#$4%_
M5`9!0=\.`````````!0```,<__^(D````#@`0@X02PX``````!0```,T__^(
ML````!``00X00@X``````(P```-,__^(J````K@`00[P"40)00"7"42=`Y\!
M2A%!?YP$!48,50H)1@Q"!D%"!D9#W]W<UPX`00M!FP5#F@9)E0M"E@I"F`A"
MF0=#G@)W"M5!UD'80=E!VD';0=Y!"UC50=9!V$'90=I!VT'>09H&FP5!VD';
M0I4+098*09@(09D'09H&09L%09X"`````!0```/<__^*T````#@`00X03`X`
M`````!P```/T__^*\````#``0@X010H.`$$+0@X`````````/```!!3__XL`
M```&*`!!#F!$"4$`GP%&G@)(G0,107^9!T2:!IL%G`0#`50*!D%&W][=W-O:
MV0X`00L``````#0```14__^0Z````+``00XP09X"0Y\!3PK?W@X`00M""4$`
M0Q%!?TX&04()00!!$4%_````````'```!(S__Y%@````,`!!#A!"$4%_1PX`
M009!``````!$```$K/__D7````%8`$$.0$()00"=`T.?`4.<!$B>`A%!?U(*
M!D%#W][=W`X`0@M-"@9!0]_>W=P.`$$+0IL%5MM$FP4```!4```$]/__DH``
M``B,`$<.X(("1PE!`)H&FP5"G`1,GP$107^7"9@(F0>=`YX"`I\*!D%(W][=
MW-O:V=C7#@!!"P*N"@9!2-_>W=S;VMG8UPX`00L`````-```!4S__YJT```"
M:`!!#D!#"4$`GP%(G`0107^;!9T#0IX"`F4*!D%$W][=W-L.`$$+``````!,
M```%A/__G.0```&P`$$.0$4)00`%1@6?`42=`Q%!?T:<!)X"80H)1@Q"!D%"
M!D9#W][=W`X`00MA"@E&#$0&1D(&04/?WMW<#@!!"P```"P```74__^R2```
M`HP`00Y`0@E!`)X"3A%!?YT#GP$"8`H&04+?WMT.`$$+`````#@```8$__^>
M%```#G``00Z``T0)00">`D.?`4H107^:!IL%G`2=`P,#@PH&047?WMW<V]H.
M`$$+`````!P```9`__^L2````'``00X00Q%!?U8.`$$&00``````1```!F#_
M_ZR8```!R`!!#C!$"4$`F@9#FP6<!$*?`4\107^=`U:9!T*8"$*>`F/>0MA!
MV4D*!D%$W]W<V]H.`$$+````````-```!JC__ZX8```!<`!!#C!#"4$`G0-"
MG@)"GP%$$4%_FP6<!`)'"@9!1-_>W=S;#@!!"P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#_____
M`````/____\``````````````````````````````````````8(!``&!_H0!
M@?Z$`8`.X`&`#N`!@%&P`8(!"`&"`1`!@@$``8("2`&!_Q`!@?Z$`8'^A`&`
M$BP!@?Z$`8'^A`&`49`!@?Z(`8("3``````!@))T`8'^B`&!_I`!@?Z0````
M``````$````!`````0```D,````!```"30````$```)J`````0```K<````/
M```$.0````P!@!'L````#0&`49`````$`8`!>`````4!@`H@````!@&`!!``
M```*```$@0````L````0````%0`````````#`8(```````(```+T````%```
M``<````7`8`.^'`````!@?_T````!P&`#J0````(```#2`````D````,````
M````````````````````````````````````````````````````````````
M``````&!_Q````````````&`4%`!@%!4`8!06`&`4%P!@%!@`8!09`&`4&@!
M@%!L`8!0<`&`4'0!@%!X`8!0?`&`4(`!@%"$`8!0B`&`4(P!@%"0`8!0E`&`
M4)@!@%"<`8!0H`&`4*0!@%"H`8!0K`&`4+`!@%"T`8!0N`&`4+P!@%#``8!0
MQ`&`4,@!@%#,`8!0T`&`4-0!@%#8`8!0W`&`4.`!@%#D`8!0Z`&`4.P!@%#P
M`8!0]`&`4/@!@%#\`8!1``&`400!@%$(`8!1#`&`41`!@%$4`8!1&`&`41P!
M@%$@`8!1)`&`42@!@%$L`8!1,`&`430!@%$X`8!1/`&`44`!@%%$`8!12/__
M__\!@@)(`8!4U$=#0SH@*$YE=$)31"!N8C(@,C`R,S`W,3`I(#$P+C4N,`!'
M0T,Z("AN8C(@,C`R,S`W,3`I(#$P+C4N,``D3F5T0E-$.B!C<G0P+E,L=B`Q
M+C<@,C`Q."\Q,2\R-B`Q-SHS-SHT-2!J;V5R9R!%>'`@)``D3F5T0E-$.B!C
M<G0P+6-O;6UO;BYC+'8@,2XR-R`R,#(R+S`V+S(Q(#`V.C4R.C$W('-K<FQL
M($5X<"`D`"1.971"4T0Z(&-R=&DN4RQV(#$N-"`R,#$T+S`S+S`V(#$Y.C`U
M.C4Y(&UA='0@17AP("0`)$YE=$)31#H@8W)T8F5G:6XN8RQV(#$N,3<@,C`Q
M."\Q,B\R."`Q.#HQ-SHQ,2!C:')I<W1O<R!%>'`@)``D3F5T0E-$.B!C<G1E
M;F0N4RQV(#$N,R`R,#$T+S`R+S(W(#$V.C0W.C0X(&UA='0@17AP("0`)$YE
M=$)31#H@8W)T;BY3+'8@,2XR(#(P,30O,#(O,C<@,38Z-#<Z-#@@;6%T="!%
M>'`@)```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N;F5T8G-D+FED96YT`"YN
M;W1E+FYE=&)S9"YP87@`+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y
M;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A
M;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1A=&$N<F5L
M+G)O`"YF:7AU<``N9V]T,@`N9'EN86UI8P`N9V]T`"YD871A`"YS9&%T80`N
M<V)S<P`N8G-S`"YC;VUM96YT````````````````````````````````````
M````````````````````````"P````$````"`8`!-````30````7````````
M```````!`````````!,````'`````@&``4P```%,````&```````````````
M!``````````F````!P````(!@`%D```!9````!0```````````````0`````
M````-P````4````"`8`!>````7@```*8````!0`````````$````!````#T`
M```+`````@&`!!````00```&$`````8````!````!````!````!%`````P``
M``(!@`H@```*(```!($```````````````$`````````30````0````"`8`.
MI```#J0```!4````!0`````````$````#````%<````$````0@&`#O@```[X
M```"]`````4````7````!`````P```!A`````0````8!@!'L```1[````"``
M``````````````0`````````9P````$````&`8`2$```$A```#^`````````
M```````0`````````&T````!````!@&`49```%&0````(```````````````
M!`````````!S`````0````(!@%&P``!1L```/P0```````````````0`````
M````>P````$````"`8"0M```D+0```#T```````````````$`````````(D`
M```!`````@&`D:@``)&H```&X```````````````!`````````"3`````0``
M``,!@?Z$``#^A`````@```````````````0`````````F@````$````#`8'^
MC```_HP````(```````````````$`````````*$````!`````P&!_I0``/Z4
M````!```````````````!`````````"F`````0````,!@?Z8``#^F````!,`
M``````````````@`````````LP````$````#`8'^K```_JP````$````````
M```````$`````````+H````!`````P&!_K```/ZP````8```````````````
M!`````````#`````!@````,!@?\0``#_$````.`````&``````````0````(
M````R0````$````#`8'_\```__`````0```````````````$````!````%P`
M```!`````P&"`````0``````_```````````````!`````````#.`````0``
M``,!@@#\``$`_`````0```````````````0`````````U`````$````#`8(!
M```!`0`````(```````````````$`````````-L````(`````P&"`0@``0$(
M````$```````````````"`````````#A````"`````,!@@$8``$!"```!6P`
M``````````````@`````````Y@````$````P```````!`0@````]````````
M```````!`````0```!\````!````,````````0%%```!4P``````````````
M`0````$````!`````P````````````$"F````.\```````````````$`````
